@@ -115,9 +115,7 @@ class RemoteAZURE(RemoteBASE):
     def _upload(
         self, from_file, to_info, name=None, no_progress_bar=False, **_kwargs
     ):
-        with Tqdm(
-            desc_truncate=name, disable=no_progress_bar, bytes=True
-        ) as pbar:
+        with Tqdm(desc=name, disable=no_progress_bar, bytes=True) as pbar:
             self.blob_service.create_blob_from_path(
                 to_info.bucket,
                 to_info.path,
@@ -128,9 +126,7 @@ class RemoteAZURE(RemoteBASE):
     def _download(
         self, from_info, to_file, name=None, no_progress_bar=False, **_kwargs
     ):
-        with Tqdm(
-            desc_truncate=name, disable=no_progress_bar, bytes=True
-        ) as pbar:
+        with Tqdm(desc=name, disable=no_progress_bar, bytes=True) as pbar:
             self.blob_service.get_blob_to_path(
                 from_info.bucket,
                 from_info.path,
