@@ -1,13 +1,17 @@
+import logging
 import os
 import shortuuid
 
 from dvc.config import Config
+from dvc.exceptions import NotDvcRepoError, UrlNotDvcRepoError
 from dvc.path_info import PathInfo
 from dvc.external_repo import external_repo
 from dvc.state import StateNoop
 from dvc.utils import remove
 from dvc.utils.compat import urlparse
 
+logger = logging.getLogger(__name__)
+
 
 @staticmethod
 def get(url, path, out=None, rev=None):
@@ -48,5 +52,8 @@ def get(url, path, out=None, rev=None):
             o.path_info = PathInfo(os.path.abspath(out))
             with o.repo.state:
                 o.checkout()
+
+    except NotDvcRepoError:
+        raise UrlNotDvcRepoError(url)
     finally:
         remove(tmp_dir)
