@@ -114,12 +114,8 @@ class Git(Base):
             )
         return False
 
-    def ignore(self, path, in_curr_dir=False):
-        base_dir = (
-            os.path.realpath(os.curdir)
-            if in_curr_dir
-            else os.path.dirname(path)
-        )
+    def ignore(self, path):
+        base_dir = os.path.dirname(path)
         entry, gitignore = self._get_gitignore(path, base_dir)
 
         if self._ignored(entry, gitignore):
@@ -216,7 +212,11 @@ class Git(Base):
         return [t.name for t in self.repo.tags]
 
     def _install_hook(self, name, cmd):
-        command = '[ -z "$(git ls-files .dvc)" ] || exec dvc {}'.format(cmd)
+        command = (
+            '[ "$3" == "0" ]'
+            ' || [ -z "$(git ls-files .dvc)" ]'
+            " || exec dvc {}".format(cmd)
+        )
 
         hook = os.path.join(self.root_dir, self.GIT_DIR, "hooks", name)
 
